@@ -123,9 +123,10 @@ class RemoteException(Exception):
 F = TypeVar("F", bound=Callable)
 
 
-def remote_api_endpoint(path) -> Callable[[F], F]:
+def remote_api_endpoint(path: str, method: str = "POST") -> Callable[[F], F]:
     def dec(f: F) -> F:
         f._endpoint_path = path  # type: ignore
+        f._method = method  # type: ignore
         return f
 
     return dec
@@ -315,13 +316,18 @@ class RPCClient(metaclass=MetaRPCClient):
                 data = self._decode_response(response, check_status=False)
                 if isinstance(data, dict):
                     for exc_type in self.reraise_exceptions:
-                        if exc_type.__name__ == data["exception"]["type"]:
-                            exception = exc_type(*data["exception"]["args"])
+                        if exc_type.__name__ == data["type"]:
+                            exception = exc_type(*data["args"])
                             break
                     else:
-                        exception = RemoteException(
-                            payload=data["exception"], response=response
-                        )
+                        # old dict encoded exception schema
+                        # TODO: Remove that code once all servers are using new schema
+                        if "exception" in data:
+                            exception = RemoteException(
+                                payload=data["exception"], response=response
+                            )
+                        else:
+                            exception = RemoteException(payload=data, response=response)
                 else:
                     exception = pickle.loads(data)
 
@@ -329,10 +335,14 @@ class RPCClient(metaclass=MetaRPCClient):
                 data = self._decode_response(response, check_status=False)
                 if "exception_pickled" in data:
                     exception = pickle.loads(data["exception_pickled"])
-                else:
+                # old dict encoded exception schema
+                # TODO: Remove that code once all servers are using new schema
+                elif "exception" in data:
                     exception = RemoteException(
                         payload=data["exception"], response=response
                     )
+                else:
+                    exception = RemoteException(payload=data, response=response)
 
         except (TypeError, pickle.UnpicklingError):
             raise RemoteException(payload=data, response=response)
@@ -429,11 +439,14 @@ class RPCServerApp(Flask):
 
     def __init__(self, *args, backend_class=None, backend_factory=None, **kwargs):
         super().__init__(*args, **kwargs)
+        if backend_class is None and backend_factory is not None:
+            raise ValueError(
+                "backend_factory should only be provided if backend_class is"
+            )
 
         self.backend_class = backend_class
         if backend_class is not None:
-            if backend_factory is None:
-                backend_factory = backend_class
+            backend_factory = backend_factory or backend_class
             for (meth_name, meth) in backend_class.__dict__.items():
                 if hasattr(meth, "_endpoint_path"):
                     self.__add_endpoint(meth_name, meth, backend_factory)
